# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_raw_global_optspecs
	string join \n t/target= d/outdir= S/silent= h/help V/version
end

function __fish_raw_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_raw_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_raw_using_subcommand
	set -l cmd (__fish_raw_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c raw -n "__fish_raw_needs_command" -s t -l target -d 'Target tarball file to extract and decompress. Supports globbing.' -r -F
complete -c raw -n "__fish_raw_needs_command" -s d -l outdir -d 'Output directory of extracted archive.' -r -F
complete -c raw -n "__fish_raw_needs_command" -s S -l silent -d 'Whether to silence the output or not.' -r -f -a "true\t''
false\t''"
complete -c raw -n "__fish_raw_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c raw -n "__fish_raw_needs_command" -s V -l version -d 'Print version'
complete -c raw -n "__fish_raw_needs_command" -f -a "generate-completions-for" -d 'Generate shell completions'
complete -c raw -n "__fish_raw_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c raw -n "__fish_raw_using_subcommand generate-completions-for" -s h -l help -d 'Print help'
complete -c raw -n "__fish_raw_using_subcommand help; and not __fish_seen_subcommand_from generate-completions-for help" -f -a "generate-completions-for" -d 'Generate shell completions'
complete -c raw -n "__fish_raw_using_subcommand help; and not __fish_seen_subcommand_from generate-completions-for help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
