# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_roast_global_optspecs
	string join \n t/target= i/include= E/exclude= A/additional-paths= f/outfile= d/outdir= p/preserve-root= r/reproducible= g/ignore-git= I/ignore-hidden= S/silent= h/help V/version
end

function __fish_roast_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_roast_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_roast_using_subcommand
	set -l cmd (__fish_roast_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c roast -n "__fish_roast_needs_command" -s t -l target -d 'Target directory to archive. This will be set as the root directory of the archive. Supports globbing.' -r -F
complete -c roast -n "__fish_roast_needs_command" -s i -l include -d 'Additional paths such as files or directories in the target directory to include to the archive. Their parent directory will be put next to the target directory\'s work directory. The work directory is based on the preserve root option. This is different from `--additional_paths`. Useful to override excluded directories. ⚠️ Careful if the archive has whether preserved root set when it was created.' -r -F
complete -c roast -n "__fish_roast_needs_command" -s E -l exclude -d 'Additional paths such as files or directories from within target directory\'s work directory to exclude when generating the archive.' -r -F
complete -c roast -n "__fish_roast_needs_command" -s A -l additional-paths -d 'Additional paths such as files or directories to add to the archive. Their parent directory will be put next to the target directory. This is different from `--include`. Optionally, one can add a path to a directory inside the archive e.g. `-A some/file/to/archive,put/where/in/archive`. If directory does not exist, it will be created.' -r
complete -c roast -n "__fish_roast_needs_command" -s f -l outfile -d 'Output file of the generated archive with path.' -r -F
complete -c roast -n "__fish_roast_needs_command" -s d -l outdir -d 'Output path of the generated archive.' -r -F
complete -c roast -n "__fish_roast_needs_command" -s p -l preserve-root -d 'Preserve root directory instead of only archiving relative paths.' -r -f -a "true\t''
false\t''"
complete -c roast -n "__fish_roast_needs_command" -s r -l reproducible -d 'Allow reproducibility for Reproducible Builds.' -r -f -a "true\t''
false\t''"
complete -c roast -n "__fish_roast_needs_command" -s g -l ignore-git -d 'Whether to ignore git related metadata, files and directories.' -r -f -a "true\t''
false\t''"
complete -c roast -n "__fish_roast_needs_command" -s I -l ignore-hidden -d 'Whether to ignore hidden directories and files or what we call dotfiles. Does not affect `--ignore-git`.' -r -f -a "true\t''
false\t''"
complete -c roast -n "__fish_roast_needs_command" -s S -l silent -d 'Whether to silence the output or not.' -r -f -a "true\t''
false\t''"
complete -c roast -n "__fish_roast_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c roast -n "__fish_roast_needs_command" -s V -l version -d 'Print version'
complete -c roast -n "__fish_roast_needs_command" -f -a "generate-completions-for" -d 'Generate shell completions'
complete -c roast -n "__fish_roast_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c roast -n "__fish_roast_using_subcommand generate-completions-for" -s h -l help -d 'Print help'
complete -c roast -n "__fish_roast_using_subcommand help; and not __fish_seen_subcommand_from generate-completions-for help" -f -a "generate-completions-for" -d 'Generate shell completions'
complete -c roast -n "__fish_roast_using_subcommand help; and not __fish_seen_subcommand_from generate-completions-for help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
